@@ -288,6 +288,7 @@ public:
     virtual bool check_semantics(string &msg, bool all = false);
 
     virtual bool ops(BaseType *b, int op);
+    virtual bool d4_ops(BaseType *b, int op);
 
     virtual unsigned int width(bool constrained = false) const;
 
@@ -475,7 +476,7 @@ public:
      */
     virtual void compute_checksum(Crc32 &checksum) = 0;
 
-    virtual void intern_data(Crc32 &checksum/*, DMR &dmr, ConstraintEvaluator &eval*/);
+    virtual void intern_data(/*Crc32 &checksum, DMR &dmr, ConstraintEvaluator &eval*/);
 
     /**
      * @brief The DAP4 serialization method.
