@@ -134,16 +134,17 @@ unsigned int Byte::width(bool) const
 */
 bool Byte::serialize(ConstraintEvaluator & eval, DDS & dds, Marshaller &m, bool ce_eval)
 {
+#if USE_LOCAL_TIMEOUT_SCHEME
     dds.timeout_on();
-
+#endif
     if (!read_p())
         read();          // read() throws Error and InternalErr
 
     if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
-
+#if USE_LOCAL_TIMEOUT_SCHEME
     dds.timeout_off();
-
+#endif
     m.put_byte( d_buf ) ;
 
     return true;
@@ -280,6 +281,16 @@ bool Byte::ops(BaseType * b, int op)
         throw InternalErr("This value not read!");
     }
 
+    // By using the same operator code numbers for both the DAP2 and DAP4
+    // parser/evaluator we can use the same evaluation code.
+    return d4_ops(b, op);
+}
+
+/**
+ * @see BaseType::d4_ops(BaseType *, int)
+ */
+bool Byte::d4_ops(BaseType *b, int op)
+{
     switch (b->type()) {
         case dods_int8_c:
             return USCmp<dods_byte, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
@@ -301,8 +312,11 @@ bool Byte::ops(BaseType * b, int op)
             return USCmp<dods_byte, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
         case dods_float64_c:
             return USCmp<dods_byte, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
+        case dods_str_c:
+        case dods_url_c:
+            throw Error(malformed_expr, "Relational operators can only compare compatible types (number, string).");
         default:
-            return false;
+            throw Error(malformed_expr, "Relational operators only work with scalar types.");
     }
 }
 
