@@ -32,6 +32,8 @@
 
 #include "config.h"
 
+//#define DODS_DEBUG
+
 #include <string>
 #include <sstream>
 #include <algorithm>
@@ -39,8 +41,6 @@
 
 #include <stdint.h>
 
-//#define DODS_DEBUG
-
 #include "crc.h"
 
 #include "Constructor.h"
@@ -132,7 +132,7 @@ Constructor::operator=(const Constructor &rhs)
     return *this;
 }
 
-// A public method, but just barely..
+// A public method, but just barely...
 BaseType *
 Constructor::transform_to_dap4(D4Group *root, Constructor *dest)
 {
@@ -478,16 +478,17 @@ Constructor::intern_data(ConstraintEvaluator & eval, DDS & dds)
 bool
 Constructor::serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval)
 {
+#if USE_LOCAL_TIMEOUT_SCHEME
     dds.timeout_on();
-
+#endif
     if (!read_p())
         read();  // read() throws Error and InternalErr
 
     if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
-
+#if USE_LOCAL_TIMEOUT_SCHEME
     dds.timeout_off();
-
+#endif
     for (Vars_iter i = d_vars.begin(); i != d_vars.end(); i++) {
         if ((*i)->send_p()) {
 #ifdef CHECKSUMS
@@ -527,11 +528,11 @@ Constructor::compute_checksum(Crc32 &)
 }
 
 void
-Constructor::intern_data(Crc32 &checksum/*, DMR &dmr, ConstraintEvaluator & eval*/)
+Constructor::intern_data(/*Crc32 &checksum, DMR &dmr, ConstraintEvaluator & eval*/)
 {
     for (Vars_iter i = d_vars.begin(); i != d_vars.end(); i++) {
         if ((*i)->send_p()) {
-            (*i)->intern_data(checksum/*, dmr, eval*/);
+            (*i)->intern_data(/*checksum, dmr, eval*/);
         }
     }
 }
@@ -637,8 +638,11 @@ Constructor::print_val(ostream &out, string space, bool print_decl_p)
     }
 
     out << "{ " ;
-    for (Vars_citer i = d_vars.begin(); i != d_vars.end();
-         i++, (void)(i != d_vars.end() && out << ", ")) {
+    for (Vars_citer i = d_vars.begin(), e = d_vars.end(); i != e;
+         i++, (void)(i != e && out << ", ")) {
+
+        DBG(cerr << (*i)->name() << " isa " << (*i)->type_name() << endl);
+
         (*i)->print_val(out, "", false);
     }
 
