@@ -29,10 +29,14 @@
 #include <cassert>
 
 #include "BaseType.h"
+#include "dods-datatypes.h"
 
+#if 0
 #include "InternalErr.h"
 #include "dods-datatypes.h"
+#include "dods-limits.h"
 #include "util.h"
+#endif
 
 namespace libdap
 {
@@ -51,60 +55,25 @@ class UnMarshaller;
  * Enumeration XML element in the DMR - that information is stored
  * in additional fields and used for checking values and printing the
  * variable's declaration, but not for the internal storage of values.
+ *
+ * @todo Note the hack to remove the union...
  */
 class D4Enum: public BaseType
 {
 	friend class D4EnumTest;
 
-public:
-    union enum_value {
-    	int8_t i8;
-    	uint8_t ui8;
-    	int16_t i16;
-    	uint16_t ui16;
-    	int32_t i32;
-    	uint32_t ui32;
-    	int64_t i64;
-    	uint64_t ui64;
-
-    	enum_value() : ui64(0) { }
-
-    	enum_value(int8_t i) : i8(i) {}
-    	enum_value(uint8_t i) : ui8(i) {}
-    	enum_value(int16_t i) : i16(i) {}
-    	enum_value(uint16_t i) : ui16(i) {}
-    	enum_value(int32_t i) : i32(i) {}
-    	enum_value(uint32_t i) : ui32(i) {}
-    	enum_value(int64_t i) : i64(i) {}
-    	enum_value(uint64_t i) : ui64(i) {}
-
-    	// cast operators; use by set_value()
-    	operator int8_t() const { return i8; }
-    	operator uint8_t() const { return ui8; }
-    	operator int16_t() const { return i16; }
-    	operator uint16_t() const { return ui16; }
-    	operator int32_t() const { return i32; }
-    	operator uint32_t() const { return ui32; }
-    	operator int64_t() const { return i64; }
-    	operator uint64_t() const { return ui64; }
-    };
+protected:
+    // Use an unsigned 64-bit int. the value() and set_value()
+    // accessors cast to other types as needed, including signed ones.
+    uint64_t d_buf;
 
 private:
-    enum_value d_buf;
-
     Type d_element_type;
-    D4EnumDef *d_enum_def;	// The enumeration defined in the DMR, not an integer type
+    D4EnumDef *d_enum_def;	// This is a weak pointer; don't delete
     bool d_is_signed;
 
     void m_duplicate(const D4Enum &src);
-#if 0
-    {
-        d_buf = src.d_buf;
-        d_element_type = src.d_element_type;
-        d_enum_def = new D4EnumDef(src.d_enum_def);
-        d_is_signed = src.d_is_signed;
-    }
-#endif
+    void m_check_value(int64_t v) const;
 
     unsigned int m_type_width() const {
         switch(d_element_type) {
@@ -131,29 +100,11 @@ private:
     D4Enum();	// No empty constructor
 
 public:
-	// TODO add a way to set the EnumDef to these
-    D4Enum(const string &name, const string &enum_type) :
-        BaseType(name, dods_enum_c, true /*is_dap4*/), d_buf((uint64_t) 0), d_element_type(dods_null_c), d_enum_def(0)
-    {
-        d_element_type = get_type(enum_type.c_str());
+    D4Enum(const string &name, const string &enum_type);
 
-        if (!is_integer_type(d_element_type)) d_element_type = dods_uint64_c;
-        set_is_signed(d_element_type);
-    }
+    D4Enum(const string &name, Type type);
 
-    D4Enum(const string &name, Type type) :
-        BaseType(name, dods_enum_c, true /*is_dap4*/), d_buf((uint64_t) 0), d_element_type(type), d_enum_def(0)
-    {
-        if (!is_integer_type(d_element_type)) d_element_type = dods_uint64_c;
-        set_is_signed(d_element_type);
-    }
-
-    D4Enum(const string &name, const string &dataset, Type type) :
-        BaseType(name, dataset, dods_enum_c, true /*is_dap4*/), d_buf((uint64_t) 0), d_element_type(type), d_enum_def(0)
-    {
-        if (!is_integer_type(d_element_type)) d_element_type = dods_uint64_c;
-        set_is_signed(d_element_type);
-    }
+    D4Enum(const string &name, const string &dataset, Type type);
 
     D4Enum(const D4Enum &src) : BaseType(src) { m_duplicate(src); }
 
@@ -176,71 +127,18 @@ public:
     void set_element_type(Type type) { d_element_type = type; }
 
     bool is_signed() const { return d_is_signed; }
-    void set_is_signed(Type t) {
-    	switch (t) {
-    	case dods_byte_c:
-    	case dods_uint8_c:
-    	case dods_uint16_c:
-    	case dods_uint32_c:
-    	case dods_uint64_c:
-    		d_is_signed = false;
-    		break;
+    void set_is_signed(Type t);
 
-    	case dods_int8_c:
-    	case dods_int16_c:
-    	case dods_int32_c:
-    	case dods_int64_c:
-    		d_is_signed =  true;
-    		break;
-
-    	default:
-    		assert(!"illegal type for D4Enum");
-    		throw InternalErr(__FILE__, __LINE__, "Illegal type");
-    	}
-    }
-
-    /**
-     * @brief Copy the value of this Enum into \c v.
-     * Template member function that can be used to read the value of the
-     * Enum. This template is explicitly instantiated so libdap includes
-     * D4Enum::value(dods_byte* v), ..., value(dods_uint64) (i.e., all
-     * of the integer types).
-     *
-     * @param v Value-result parameter; return the value of the Enum
-     * in this variable.
-     */
-	template<typename T> void value(T *v) const
-	{
-		switch (d_element_type) {
-		case dods_byte_c:
-		case dods_uint8_c:
-			*v = static_cast<T>(d_buf.ui8);
-			break;
-		case dods_uint16_c:
-			*v = static_cast<T>(d_buf.ui16);
-			break;
-		case dods_uint32_c:
-			*v = static_cast<T>(d_buf.ui32);
-			break;
-		case dods_uint64_c:
-			*v = static_cast<T>(d_buf.ui64);
-			break;
-
-		case dods_int8_c:
-			*v = static_cast<T>(d_buf.i8);
-			break;
-		case dods_int16_c:
-			*v = static_cast<T>(d_buf.i16);
-			break;
-		case dods_int32_c:
-			*v = static_cast<T>(d_buf.i32);
-			break;
-		case dods_int64_c:
-			*v = static_cast<T>(d_buf.i64);
-			break;
-		default:
-			assert(!"illegal type for D4Enum");
-		}
+	/**
+	 * @brief Get the value of an Enum
+	 * Get the value of this instance. The caller is responsible
+	 * for using a type T than can hold the value.
+	 *
+	 * @param v Value-result parameter; return the value of the Enum
+	 * in this variable.
+	 */
+	template<typename T> void value(T *v) const {
+		*v = static_cast<T>(d_buf);
 	}
 
     /**
@@ -250,19 +148,31 @@ public:
      * types for the parameter \c v.
      *
      * @param v Set the Enum to this value.
+     * @param check_value If true test the value 'v' against the type of the
+     * Enum. Defaults to true.
      */
-    template <typename T> void set_value(T v) { d_buf = v; }
+    template <typename T> void set_value(T v, bool check_value = true)
+    {
+    	if (check_value) m_check_value(v);
+    	d_buf = static_cast<int64_t>(v);
+    }
 
     /**
      * @brief Return the number of bytes in an instance of an Enum.
      * This returns the number of bytes an instance of Enum will use
-     * either in memory or on the wire (i.e., in a serialization of
-     * the type).
+     * in memory or on the wire (i.e., in a serialization of
+     * the type). On the wire this type uses the minimum number of
+     * bytes for the given Enum type - an Enum with type Byte uses
+     * one byte, Int16 uses two, and so on. In memory, a single instance
+     * uses 64-bits but a vector of these will use the same number of
+     * bytes per value as the on-the-wire representation.
+     *
+     * @note The private method m_type_width() returns the byte width
+     * used for the on-the-wire representation of values.
      *
-     * @note This version of the method works for scalar Enums only.
      * @return The number of bytes used by a value.
      */
-    virtual unsigned int width(bool /* constrained */ = false) const { return m_type_width(); }
+    virtual unsigned int width(bool /* constrained */ = false) const { return /*sizeof(int64_t);*/ m_type_width();}
 
     // DAP4
     virtual void compute_checksum(Crc32 &checksum);
