@@ -23,6 +23,7 @@
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
 #include "config.h"
+// #define DODS_DEBUG 1
 
 #include <iostream>
 #include <sstream>
@@ -30,8 +31,6 @@
 
 #include <stdint.h>
 
-//#define DODS_DEBUG
-
 #include "crc.h"
 
 #include "BaseType.h"
@@ -48,6 +47,13 @@
 
 #include "debug.h"
 
+/**
+ * Define this symbol iff we decide to include information about the
+ * byte order of the response (as sent from the server) so that the
+ * client can determine the correct CRC32 hash code. jhrg 1/4/16
+ */
+#undef INCLUDE_SOURCE_BYTE_ORDER
+
 namespace libdap {
 
 void D4Group::m_duplicate(const D4Group &g)
@@ -100,6 +106,10 @@ void D4Group::m_duplicate(const D4Group &g)
     to be created. The name may be omitted, which will create a
     nameless variable. This may be adequate for some applications.
 
+    @note This type is available in DAP4 only.
+    See http://docs.opendap.org/index.php/DAP4:_Specification_Volume_1#Groups
+
+
     @param n A string containing the name of the variable.
 */
 D4Group::D4Group(const string &name)
@@ -110,6 +120,9 @@ D4Group::D4Group(const string &name)
     to be created and the dataset name from which this variable is being
     created. Used on server-side handlers.
 
+    @note This type is available in DAP4 only.
+    See http://docs.opendap.org/index.php/DAP4:_Specification_Volume_1#Groups
+
     @param n A string containing the name of the variable.
     @param d A string containing the name of the dataset.
 */
@@ -430,11 +443,11 @@ D4Group::set_send_p(bool state)
 }
 
 void
-D4Group::intern_data(Crc32 &checksum/*, DMR &dmr, ConstraintEvaluator &eval*/)
+D4Group::intern_data(/*Crc32 &checksum, DMR &dmr, ConstraintEvaluator &eval*/)
 {
     groupsIter g = d_groups.begin();
     while (g != d_groups.end())
-        (*g++)->intern_data(checksum/*, dmr, eval*/);
+        (*g++)->intern_data(/*checksum, dmr, eval*/);
 
     // Specialize how the top-level variables in any Group are sent; include
     // a checksum for them. A subset operation might make an interior set of
@@ -446,17 +459,26 @@ D4Group::intern_data(Crc32 &checksum/*, DMR &dmr, ConstraintEvaluator &eval*/)
 	for (Vars_iter i = d_vars.begin(); i != d_vars.end(); i++) {
 		// Only send the stuff in the current subset.
 		if ((*i)->send_p()) {
-			checksum.Reset();
-
-			(*i)->intern_data(checksum/*, dmr, eval*/);
-
+#if 0
+		    checksum.Reset();
+#endif
+			(*i)->intern_data(/*checksum, dmr, eval*/);
+#if 0
 			D4Attribute *a = new D4Attribute("DAP4_Checksum_CRC32", attr_str_c);
-		    ostringstream oss;
+
+			ostringstream oss;
 		    oss.setf(ios::hex, ios::basefield);
 		    oss << setfill('0') << setw(8) << checksum.GetCrc32();
-		    a->add_value(oss.str());
-			(*i)->attributes()->add_attribute_nocopy(a);
+            a->add_value(oss.str());
+#if INCLUDE_SOURCE_BYTE_ORDER
+	        if (um.is_source_big_endian())
+	            a->add_value("source:big-endian");
+	        else
+	            a->add_value("source:little-endian");
+#endif
+	        (*i)->attributes()->add_attribute_nocopy(a);
 			DBG(cerr << "CRC32: " << oss.str() << " for " << (*i)->name() << endl);
+#endif
 		}
 	}
 }
@@ -503,6 +525,7 @@ D4Group::serialize(D4StreamMarshaller &m, DMR &dmr, /*ConstraintEvaluator &eval,
 		if ((*i)->send_p()) {
 			m.reset_checksum();
 
+	        DBG(cerr << "Serializing variable " << (*i)->type_name() << " " << (*i)->name() << endl);
 			(*i)->serialize(m, dmr, /*eval,*/ filter);
 
 			DBG(cerr << "Wrote CRC32: " << m.get_checksum() << " for " << (*i)->name() << endl);
@@ -514,17 +537,25 @@ D4Group::serialize(D4StreamMarshaller &m, DMR &dmr, /*ConstraintEvaluator &eval,
 void D4Group::deserialize(D4StreamUnMarshaller &um, DMR &dmr)
 {
 	groupsIter g = d_groups.begin();
-	while (g != d_groups.end())
+	while (g != d_groups.end()) {
+        DBG(cerr << "Deserializing group " << (*g)->name() << endl);
 		(*g++)->deserialize(um, dmr);
-
+	}
 	// Specialize how the top-level variables in any Group are received; read
 	// their checksum and store the value in a magic attribute of the variable
 	for (Vars_iter i = d_vars.begin(); i != d_vars.end(); i++) {
+        DBG(cerr << "Deserializing variable " << (*i)->type_name() << " " << (*i)->name() << endl);
 		(*i)->deserialize(um, dmr);
 
 		D4Attribute *a = new D4Attribute("DAP4_Checksum_CRC32", attr_str_c);
 		string crc = um.get_checksum_str();
 		a->add_value(crc);
+#if INCLUDE_SOURCE_BYTE_ORDER
+		if (um.is_source_big_endian())
+		    a->add_value("source:big-endian");
+		else
+		    a->add_value("source:little-endian");
+#endif
 		DBG(cerr << "Read CRC32: " << crc << " for " << (*i)->name() << endl);
 		(*i)->attributes()->add_attribute_nocopy(a);
 	}
