@@ -79,6 +79,9 @@ namespace libdap {
     to be created.  The name may be omitted, which will create a
     nameless variable.  This may be adequate for some applications.
 
+    @note This type is available in DAP4 only.
+    See http://docs.opendap.org/index.php/DAP4:_Specification_Volume_1#Atomic_Types
+
     @param n A string containing the name of the variable to be
     created.
 */
@@ -88,6 +91,9 @@ Int64::Int64(const string &n) : BaseType(n, dods_int64_c, true /*is_dap4*/), d_b
 /** The Int64 server-side constructor accepts the name of the variable and
     the dataset name from which this instance is created.
 
+    @note This type is available in DAP4 only.
+    See http://docs.opendap.org/index.php/DAP4:_Specification_Volume_1#Atomic_Types
+
     @param n A string containing the name of the variable to be created.
     @param d A string containing the name of the dataset from which this
     variable is created
@@ -195,6 +201,16 @@ Int64::ops(BaseType *b, int op)
     if (!b->read_p() && !b->read())
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
 
+    return d4_ops(b, op);
+
+    return false;
+}
+
+/**
+ * @see BaseType::d4_ops(BaseType *, int)
+ */
+bool Int64::d4_ops(BaseType *b, int op)
+{
     switch (b->type()) {
         case dods_int8_c:
             return Cmp<dods_int64, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
@@ -216,11 +232,12 @@ Int64::ops(BaseType *b, int op)
             return Cmp<dods_int64, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
         case dods_float64_c:
             return Cmp<dods_int64, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
+        case dods_str_c:
+        case dods_url_c:
+            throw Error(malformed_expr, "Relational operators can only compare compatible types (number, string).");
         default:
-            return false;
+            throw Error(malformed_expr, "Relational operators only work with scalar types.");
     }
-
-    return false;
 }
 
 /** @brief dumps information about this object
