@@ -58,20 +58,26 @@ namespace libdap {
 
 /** The UInt64 constructor accepts the name of the variable to be created.
 
+    @note This type is available in DAP4 only.
+    See http://docs.opendap.org/index.php/DAP4:_Specification_Volume_1#Atomic_Types
+
     @param n A string containing the name of the variable to be created.
     variable is created
 */
-UInt64::UInt64(const string &n) : BaseType(n, dods_uint64_c), d_buf(0)
+UInt64::UInt64(const string &n) : BaseType(n, dods_uint64_c, true /*is_dap4*/), d_buf(0)
 {}
 
 /** The UInt64 server-side constructor accepts the name of the variable and
     the dataset name from which this instance is created.
 
+    @note This type is available in DAP4 only.
+    See http://docs.opendap.org/index.php/DAP4:_Specification_Volume_1#Atomic_Types
+
     @param n A string containing the name of the variable to be created.
     @param d A string containing the name of the dataset from which this
     variable is created
 */
-UInt64::UInt64(const string &n, const string &d)  : BaseType(n, d, dods_uint64_c), d_buf(0)
+UInt64::UInt64(const string &n, const string &d)  : BaseType(n, d, dods_uint64_c, true /*is_dap4*/), d_buf(0)
 {}
 
 UInt64::UInt64(const UInt64 &copy_from) : BaseType(copy_from)
@@ -196,6 +202,35 @@ UInt64::ops(BaseType *b, int op)
     }
 }
 
+bool
+UInt64::d4_ops(BaseType *b, int op)
+{
+    switch (b->type()) {
+        case dods_int8_c:
+            return USCmp<dods_uint64, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
+        case dods_byte_c:
+            return Cmp<dods_uint64, dods_byte>(op, d_buf, static_cast<Byte*>(b)->value());
+        case dods_int16_c:
+            return USCmp<dods_uint64, dods_int16>(op, d_buf, static_cast<Int16*>(b)->value());
+        case dods_uint16_c:
+            return Cmp<dods_uint64, dods_uint16>(op, d_buf, static_cast<UInt16*>(b)->value());
+        case dods_int32_c:
+            return USCmp<dods_uint64, dods_int32>(op, d_buf, static_cast<Int32*>(b)->value());
+        case dods_uint32_c:
+            return Cmp<dods_uint64, dods_uint32>(op, d_buf, static_cast<UInt32*>(b)->value());
+        case dods_int64_c:
+            return USCmp<dods_uint64, dods_int64>(op, d_buf, static_cast<Int64*>(b)->value());
+        case dods_uint64_c:
+            return Cmp<dods_uint64, dods_uint64>(op, d_buf, static_cast<UInt64*>(b)->value());
+        case dods_float32_c:
+            return USCmp<dods_uint64, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
+        case dods_float64_c:
+            return USCmp<dods_uint64, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
+        default:
+            return false;
+    }
+}
+
 /** @brief dumps information about this object
  *
  * Displays the pointer value of this instance and information about this
