@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.1.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.1"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -226,7 +226,7 @@ rvalue *build_constant_array(vector<t> *values, DDS *dds);
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
 #line 145 "ce_expr.yy" /* yacc.c:355  */
@@ -264,6 +264,8 @@ union YYSTYPE
 
 #line 266 "ce_expr.tab.cc" /* yacc.c:355  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
@@ -277,7 +279,7 @@ int ce_exprparse (ce_parser_arg *arg);
 
 /* Copy the second part of user declarations.  */
 
-#line 281 "ce_expr.tab.cc" /* yacc.c:358  */
+#line 283 "ce_expr.tab.cc" /* yacc.c:358  */
 /* Unqualified %code blocks.  */
 #line 232 "ce_expr.yy" /* yacc.c:359  */
 
@@ -285,7 +287,7 @@ int ce_exprparse (ce_parser_arg *arg);
    be used during the paraent rule's parse. See fast_int32_arg_list. */
 unsigned long arg_length_hint_value = 0;
 
-#line 289 "ce_expr.tab.cc" /* yacc.c:359  */
+#line 291 "ce_expr.tab.cc" /* yacc.c:359  */
 
 #ifdef short
 # undef short
@@ -1478,13 +1480,13 @@ yyreduce:
 		     DDS(arg)->mark_all(true);
 		     (yyval.boolean) = true;
 		 }
-#line 1482 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1484 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 4:
 #line 249 "ce_expr.yy" /* yacc.c:1646  */
     { DDS(arg)->mark_all(true); }
-#line 1488 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1490 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 5:
@@ -1492,7 +1494,7 @@ yyreduce:
     { 
 		     (yyval.boolean) = (yyvsp[0].boolean);
 		 }
-#line 1496 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1498 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 6:
@@ -1500,7 +1502,7 @@ yyreduce:
     {
 		     (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean);
 		 }
-#line 1504 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1506 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 8:
@@ -1508,7 +1510,7 @@ yyreduce:
     {
 		     (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean);
 		 }
-#line 1512 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1514 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 9:
@@ -1524,7 +1526,7 @@ yyreduce:
 			     no_such_ident(arg, (yyvsp[0].id), "identifier");
 		     }
 		}
-#line 1528 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1530 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 10:
@@ -1532,7 +1534,7 @@ yyreduce:
     {
 		    (yyval.boolean) = (yyvsp[0].boolean);
 		}
-#line 1536 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1538 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 11:
@@ -1540,7 +1542,7 @@ yyreduce:
     {
 		    (yyval.boolean) = (yyvsp[0].boolean);
 		}
-#line 1544 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1546 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 12:
@@ -1562,7 +1564,7 @@ yyreduce:
                 return false;
             }
         }
-#line 1566 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1568 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 13:
@@ -1570,7 +1572,7 @@ yyreduce:
     {
             (yyval.rval_ptr) = build_constant_array<dods_byte, Byte>((yyvsp[-1].byte_values), DDS(arg));
         }
-#line 1574 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1576 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 14:
@@ -1578,7 +1580,7 @@ yyreduce:
     {
             (yyval.rval_ptr) = build_constant_array<dods_int16, Int16>((yyvsp[-1].int16_values), DDS(arg));
         }
-#line 1582 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1584 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 15:
@@ -1586,7 +1588,7 @@ yyreduce:
     {
             (yyval.rval_ptr) = build_constant_array<dods_uint16, UInt16>((yyvsp[-1].uint16_values), DDS(arg));
         }
-#line 1590 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1592 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 16:
@@ -1594,7 +1596,7 @@ yyreduce:
     {
             (yyval.rval_ptr) = build_constant_array<dods_int32, Int32>((yyvsp[-1].int32_values), DDS(arg));
         }
-#line 1598 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1600 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 17:
@@ -1602,7 +1604,7 @@ yyreduce:
     {
             (yyval.rval_ptr) = build_constant_array<dods_uint32, UInt32>((yyvsp[-1].uint32_values), DDS(arg));
         }
-#line 1606 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1608 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 18:
@@ -1610,7 +1612,7 @@ yyreduce:
     {
             (yyval.rval_ptr) = build_constant_array<dods_float32, Float32>((yyvsp[-1].float32_values), DDS(arg));
         }
-#line 1614 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1616 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 19:
@@ -1618,19 +1620,19 @@ yyreduce:
     {
             (yyval.rval_ptr) = build_constant_array<dods_float64, Float64>((yyvsp[-1].float64_values), DDS(arg));
         }
-#line 1622 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1624 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 20:
 #line 356 "ce_expr.yy" /* yacc.c:1646  */
     {
               if (!check_int32((yyvsp[0].id)))
-                  throw Error(malformed_expr, "#<type>(hint, value, ...) special form expected hint to be an integer");
+                  throw Error(malformed_expr, "$<type>(hint, value, ...) special form expected hint to be an integer");
                    
               arg_length_hint_value = atoi((yyvsp[0].id));
               (yyval.boolean) = true;
           }
-#line 1634 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1636 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 21:
@@ -1638,7 +1640,7 @@ yyreduce:
     {
               (yyval.byte_values) = make_fast_arg_list<byte_arg_list, dods_byte>(arg_length_hint_value, (yyvsp[0].byte_value));
           }
-#line 1642 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1644 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 22:
@@ -1646,7 +1648,7 @@ yyreduce:
     {
               (yyval.byte_values) = make_fast_arg_list<byte_arg_list, dods_byte>((yyvsp[-2].byte_values), (yyvsp[0].byte_value));
           }
-#line 1650 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1652 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 23:
@@ -1654,7 +1656,7 @@ yyreduce:
     {
               (yyval.byte_value) = strtol((yyvsp[0].id), 0, 0);
           }
-#line 1658 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1660 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 24:
@@ -1662,7 +1664,7 @@ yyreduce:
     {
               (yyval.int16_values) = make_fast_arg_list<int16_arg_list, dods_int16>(arg_length_hint_value, (yyvsp[0].int16_value));
           }
-#line 1666 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1668 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 25:
@@ -1670,7 +1672,7 @@ yyreduce:
     {
               (yyval.int16_values) = make_fast_arg_list<int16_arg_list, dods_int16>((yyvsp[-2].int16_values), (yyvsp[0].int16_value));
           }
-#line 1674 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1676 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 26:
@@ -1678,7 +1680,7 @@ yyreduce:
     {
               (yyval.int16_value) = strtol((yyvsp[0].id), 0, 0);
           }
-#line 1682 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1684 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 27:
@@ -1686,7 +1688,7 @@ yyreduce:
     {
               (yyval.uint16_values) = make_fast_arg_list<uint16_arg_list, dods_uint16>(arg_length_hint_value, (yyvsp[0].uint16_value));
           }
-#line 1690 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1692 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 28:
@@ -1694,7 +1696,7 @@ yyreduce:
     {
               (yyval.uint16_values) = make_fast_arg_list<uint16_arg_list, dods_uint16>((yyvsp[-2].uint16_values), (yyvsp[0].uint16_value));
           }
-#line 1698 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1700 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 29:
@@ -1702,7 +1704,7 @@ yyreduce:
     {
               (yyval.uint16_value) = strtoul((yyvsp[0].id), 0, 0);
           }
-#line 1706 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1708 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 30:
@@ -1710,7 +1712,7 @@ yyreduce:
     {
               (yyval.int32_values) = make_fast_arg_list<int32_arg_list, dods_int32>(arg_length_hint_value, (yyvsp[0].int32_value));
           }
-#line 1714 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1716 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 31:
@@ -1718,7 +1720,7 @@ yyreduce:
     {
               (yyval.int32_values) = make_fast_arg_list<int32_arg_list, dods_int32>((yyvsp[-2].int32_values), (yyvsp[0].int32_value));
           }
-#line 1722 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1724 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 32:
@@ -1726,7 +1728,7 @@ yyreduce:
     {
               (yyval.int32_value) = strtol((yyvsp[0].id), 0, 0);
           }
-#line 1730 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1732 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 33:
@@ -1734,7 +1736,7 @@ yyreduce:
     {
               (yyval.uint32_values) = make_fast_arg_list<uint32_arg_list, dods_uint32>(arg_length_hint_value, (yyvsp[0].uint32_value));
           }
-#line 1738 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1740 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 34:
@@ -1742,7 +1744,7 @@ yyreduce:
     {
               (yyval.uint32_values) = make_fast_arg_list<uint32_arg_list, dods_uint32>((yyvsp[-2].uint32_values), (yyvsp[0].uint32_value));
           }
-#line 1746 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1748 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 35:
@@ -1750,7 +1752,7 @@ yyreduce:
     {
               (yyval.uint32_value) = strtoul((yyvsp[0].id), 0, 0);
           }
-#line 1754 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1756 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 36:
@@ -1758,7 +1760,7 @@ yyreduce:
     {
               (yyval.float32_values) = make_fast_arg_list<float32_arg_list, dods_float32>(arg_length_hint_value, (yyvsp[0].float32_value));
           }
-#line 1762 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1764 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 37:
@@ -1766,7 +1768,7 @@ yyreduce:
     {
               (yyval.float32_values) = make_fast_arg_list<float32_arg_list, dods_float32>((yyvsp[-2].float32_values), (yyvsp[0].float32_value));
           }
-#line 1770 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1772 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 38:
@@ -1774,7 +1776,7 @@ yyreduce:
     {
               (yyval.float32_value) = strtof((yyvsp[0].id), 0);
           }
-#line 1778 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1780 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 39:
@@ -1782,7 +1784,7 @@ yyreduce:
     {
               (yyval.float64_values) = make_fast_arg_list<float64_arg_list, dods_float64>(arg_length_hint_value, (yyvsp[0].float64_value));
           }
-#line 1786 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1788 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 40:
@@ -1790,7 +1792,7 @@ yyreduce:
     {
               (yyval.float64_values) = make_fast_arg_list<float64_arg_list, dods_float64>((yyvsp[-2].float64_values), (yyvsp[0].float64_value));
           }
-#line 1794 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1796 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 41:
@@ -1798,7 +1800,7 @@ yyreduce:
     {
               (yyval.float64_value) = strtod((yyvsp[0].id), 0);
           }
-#line 1802 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1804 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 42:
@@ -1822,7 +1824,7 @@ yyreduce:
 			    no_such_func(arg, (yyvsp[-3].id));
 		    }
 		}
-#line 1826 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1828 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 44:
@@ -1830,7 +1832,7 @@ yyreduce:
     {
 		    (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean);
 		}
-#line 1834 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1836 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 45:
@@ -1843,7 +1845,7 @@ yyreduce:
 		    else
 			(yyval.boolean) = false;
 		}
-#line 1847 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1849 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 46:
@@ -1858,7 +1860,7 @@ yyreduce:
 		    else
 			(yyval.boolean) = false;
 		}
-#line 1862 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1864 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 47:
@@ -1866,7 +1868,7 @@ yyreduce:
     {
 		    (yyval.boolean) = (yyvsp[0].boolean);
 		}
-#line 1870 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1872 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 48:
@@ -1881,7 +1883,7 @@ yyreduce:
 		       (yyval.boolean) = true;
 		   }
 	       }
-#line 1885 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1887 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 50:
@@ -1895,7 +1897,7 @@ yyreduce:
 			    no_such_func(arg, (yyvsp[-3].id));
 		    }
 		}
-#line 1899 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1901 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 51:
@@ -1903,7 +1905,7 @@ yyreduce:
     {
             (yyval.rval_ptr) = (yyvsp[0].rval_ptr);
         }
-#line 1907 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1909 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 52:
@@ -1911,7 +1913,7 @@ yyreduce:
     {
             (yyval.rval_ptr) = (yyvsp[0].rval_ptr);
         }
-#line 1915 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1917 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 53:
@@ -1922,7 +1924,7 @@ yyreduce:
 		    else
 			    (yyval.r_val_l_ptr) = 0;
 		}
-#line 1926 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1928 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 54:
@@ -1933,7 +1935,7 @@ yyreduce:
 		    else
 			    (yyval.r_val_l_ptr) = 0;
 		}
-#line 1937 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1939 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 55:
@@ -1941,7 +1943,7 @@ yyreduce:
     {  
 		      (yyval.r_val_l_ptr) = (yyvsp[0].r_val_l_ptr);
 	      }
-#line 1945 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1947 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 56:
@@ -1949,7 +1951,7 @@ yyreduce:
     { 
 		      (yyval.r_val_l_ptr) = 0; 
 	      }
-#line 1953 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1955 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 57:
@@ -1991,7 +1993,7 @@ yyreduce:
 			    (yyval.rval_ptr) = new rvalue(btp);
 		    }
 		}
-#line 1995 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 1997 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 58:
@@ -2014,7 +2016,7 @@ yyreduce:
 		    // See ticket 2240. jhrg 7/30/14
 		    delete (yyvsp[0].val).v.s;
                 }
-#line 2018 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2020 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 59:
@@ -2029,7 +2031,7 @@ yyreduce:
                     DDS(arg)->mark((yyvsp[-1].id), true);
                     (yyval.rval_ptr) = new rvalue(DDS(arg)->var((yyvsp[-1].id)));
                 }
-#line 2033 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2035 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 60:
@@ -2037,7 +2039,7 @@ yyreduce:
     {
                     (yyval.boolean) = (*DDS(arg)).mark((yyvsp[0].id), true);
                 }
-#line 2041 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2043 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 61:
@@ -2050,7 +2052,7 @@ yyreduce:
                     strncpy((yyval.id), (yyvsp[-1].id), ID_MAX-1);
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2054 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2056 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 62:
@@ -2060,7 +2062,7 @@ yyreduce:
                     strncpy((yyval.id), name.c_str(), ID_MAX-1);
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2064 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2066 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 63:
@@ -2073,7 +2075,7 @@ yyreduce:
                     strncpy((yyval.id), name.c_str(), ID_MAX-1);
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2077 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2079 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 64:
@@ -2082,7 +2084,7 @@ yyreduce:
                     strncpy((yyval.id), www2id((yyvsp[0].id)).c_str(), ID_MAX-1);
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2086 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2088 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 65:
@@ -2098,7 +2100,7 @@ yyreduce:
 
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2102 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2104 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 66:
@@ -2106,7 +2108,7 @@ yyreduce:
     {
 		    (yyval.int_ll_ptr) = make_array_indices((yyvsp[0].int_l_ptr));
 		}
-#line 2110 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2112 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 67:
@@ -2114,7 +2116,7 @@ yyreduce:
     {
 		    (yyval.int_ll_ptr) = append_array_index((yyvsp[-1].int_ll_ptr), (yyvsp[0].int_l_ptr));
 		}
-#line 2118 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2120 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 68:
@@ -2127,7 +2129,7 @@ yyreduce:
     i.v.i = atoi((yyvsp[-1].id));
     (yyval.int_l_ptr) = make_array_index(i);
 }
-#line 2131 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2133 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 69:
@@ -2138,7 +2140,7 @@ yyreduce:
     i.v.i =-1;
     (yyval.int_l_ptr) = make_array_index(i);
 }
-#line 2142 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2144 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 70:
@@ -2154,7 +2156,7 @@ yyreduce:
     j.v.i = atoi((yyvsp[-1].id));
     (yyval.int_l_ptr) = make_array_index(i, j);
 }
-#line 2158 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2160 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 71:
@@ -2169,7 +2171,7 @@ yyreduce:
     j.v.i = -1;
     (yyval.int_l_ptr) = make_array_index(i, j);
 }
-#line 2173 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2175 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 72:
@@ -2188,7 +2190,7 @@ yyreduce:
     k.v.i = atoi((yyvsp[-1].id));
     (yyval.int_l_ptr) = make_array_index(i, j, k);
 }
-#line 2192 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2194 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
   case 73:
@@ -2206,11 +2208,11 @@ yyreduce:
     k.v.i = -1;
     (yyval.int_l_ptr) = make_array_index(i, j, k);
 }
-#line 2210 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2212 "ce_expr.tab.cc" /* yacc.c:1646  */
     break;
 
 
-#line 2214 "ce_expr.tab.cc" /* yacc.c:1646  */
+#line 2216 "ce_expr.tab.cc" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2448,28 +2450,30 @@ yyreturn:
 void
 ce_exprerror(ce_parser_arg *, const string &s)
 {
-    //ce_exprerror(s.c_str());
-    string msg = "Constraint expression parse error: " + (string) s;
+    string msg = "Constraint expression parse error: " +s;
     throw Error(malformed_expr, msg);
 }
 
 void ce_exprerror(ce_parser_arg *, const string &s, const string &s2)
 {
-    //ce_exprerror(s.c_str(), s2.c_str());
-    string msg = "Constraint expression parse error: " + (string) s + ": " + (string) s2;
+    string msg = "Constraint expression parse error: " + s + ": " + s2;
     throw Error(malformed_expr, msg);    
 }
 
 void no_such_ident(ce_parser_arg *arg, const string &name, const string &word)
 {
+#if 0
     string msg = "No such " + word + " in dataset";
-    ce_exprerror(arg, msg /*.c_str()*/, name);
+    ce_exprerror(arg, msg , name);
+#endif
+    string msg = "Constraint expression parse error: No such " + word + " in dataset: " + name;
+    throw Error(no_such_variable, msg);    
+    
 }
 
 void no_such_func(ce_parser_arg *arg, const string &name)
 {
     ce_exprerror(arg, "Not a registered function", name);
-    //no_such_func(name/*.c_str()*/);
 }
 
 /* If we're calling this, assume var is not a Sequence. But assume that the
