@@ -1,8 +1,8 @@
-// A Bison parser, made by GNU Bison 3.0.1.
+// A Bison parser, made by GNU Bison 3.0.4.
 
 // Skeleton implementation for Bison LALR(1) parsers in C++
 
-// Copyright (C) 2002-2013 Free Software Foundation, Inc.
+// Copyright (C) 2002-2015 Free Software Foundation, Inc.
 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 
 // First part of user declarations.
 
-#line 37 "d4_function_parser.tab.cc" // lalr1.cc:399
+#line 37 "d4_function_parser.tab.cc" // lalr1.cc:404
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -47,9 +47,9 @@
 
 // User implementation prologue.
 
-#line 51 "d4_function_parser.tab.cc" // lalr1.cc:407
+#line 51 "d4_function_parser.tab.cc" // lalr1.cc:412
 // Unqualified %code blocks.
-#line 77 "d4_function_parser.yy" // lalr1.cc:408
+#line 77 "d4_function_parser.yy" // lalr1.cc:413
 
     #include "BaseType.h"
     #include "DMR.h"
@@ -69,7 +69,7 @@
                      libdap::D4FunctionScanner  &scanner,
                      libdap::D4FunctionEvaluator   &evaluator);
 
-#line 73 "d4_function_parser.tab.cc" // lalr1.cc:408
+#line 73 "d4_function_parser.tab.cc" // lalr1.cc:413
 
 
 #ifndef YY_
@@ -146,16 +146,16 @@
 #endif // !YYDEBUG
 
 #define yyerrok         (yyerrstatus_ = 0)
-#define yyclearin       (yyempty = true)
+#define yyclearin       (yyla.clear ())
 
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
 #define YYERROR         goto yyerrorlab
 #define YYRECOVERING()  (!!yyerrstatus_)
 
-#line 34 "d4_function_parser.yy" // lalr1.cc:474
+#line 34 "d4_function_parser.yy" // lalr1.cc:479
 namespace libdap {
-#line 159 "d4_function_parser.tab.cc" // lalr1.cc:474
+#line 159 "d4_function_parser.tab.cc" // lalr1.cc:479
 
   /* Return YYSTR after stripping away unnecessary quotes and
      backslashes, so that it's suitable for yyerror.  The heuristic is
@@ -534,9 +534,19 @@ namespace libdap {
   template <typename Base>
   inline
   D4FunctionParser::basic_symbol<Base>::~basic_symbol ()
+  {
+    clear ();
+  }
+
+  template <typename Base>
+  inline
+  void
+  D4FunctionParser::basic_symbol<Base>::clear ()
   {
     // User destructor.
     symbol_number_type yytype = this->type_get ();
+    basic_symbol<Base>& yysym = *this;
+    (void) yysym;
     switch (yytype)
     {
    default:
@@ -632,6 +642,15 @@ namespace libdap {
         break;
     }
 
+    Base::clear ();
+  }
+
+  template <typename Base>
+  inline
+  bool
+  D4FunctionParser::basic_symbol<Base>::empty () const
+  {
+    return Base::type_get () == empty_symbol;
   }
 
   template <typename Base>
@@ -734,7 +753,7 @@ namespace libdap {
   // by_type.
   inline
   D4FunctionParser::by_type::by_type ()
-     : type (empty)
+    : type (empty_symbol)
   {}
 
   inline
@@ -747,12 +766,19 @@ namespace libdap {
     : type (yytranslate_ (t))
   {}
 
+  inline
+  void
+  D4FunctionParser::by_type::clear ()
+  {
+    type = empty_symbol;
+  }
+
   inline
   void
   D4FunctionParser::by_type::move (by_type& that)
   {
     type = that.type;
-    that.type = empty;
+    that.clear ();
   }
 
   inline
@@ -893,7 +919,7 @@ namespace libdap {
   // by_state.
   inline
   D4FunctionParser::by_state::by_state ()
-    : state (empty)
+    : state (empty_state)
   {}
 
   inline
@@ -901,12 +927,19 @@ namespace libdap {
     : state (other.state)
   {}
 
+  inline
+  void
+  D4FunctionParser::by_state::clear ()
+  {
+    state = empty_state;
+  }
+
   inline
   void
   D4FunctionParser::by_state::move (by_state& that)
   {
     state = that.state;
-    that.state = empty;
+    that.clear ();
   }
 
   inline
@@ -918,7 +951,10 @@ namespace libdap {
   D4FunctionParser::symbol_number_type
   D4FunctionParser::by_state::type_get () const
   {
-    return state == empty ? 0 : yystos_[state];
+    if (state == empty_state)
+      return empty_symbol;
+    else
+      return yystos_[state];
   }
 
   inline
@@ -1019,7 +1055,7 @@ namespace libdap {
     }
 
     // that is emptied.
-    that.type = empty;
+    that.type = empty_symbol;
   }
 
   inline
@@ -1138,6 +1174,10 @@ namespace libdap {
     std::ostream& yyoutput = yyo;
     YYUSE (yyoutput);
     symbol_number_type yytype = yysym.type_get ();
+    // Avoid a (spurious) G++ 4.8 warning about "array subscript is
+    // below array bounds".
+    if (yysym.empty ())
+      std::abort ();
     yyo << (yytype < yyntokens_ ? "token" : "nterm")
         << ' ' << yytname_[yytype] << " ("
         << yysym.location << ": ";
@@ -1198,13 +1238,13 @@ namespace libdap {
 #endif // YYDEBUG
 
   inline D4FunctionParser::state_type
-  D4FunctionParser::yy_lr_goto_state_ (state_type yystate, int yylhs)
+  D4FunctionParser::yy_lr_goto_state_ (state_type yystate, int yysym)
   {
-    int yyr = yypgoto_[yylhs - yyntokens_] + yystate;
+    int yyr = yypgoto_[yysym - yyntokens_] + yystate;
     if (0 <= yyr && yyr <= yylast_ && yycheck_[yyr] == yystate)
       return yytable_[yyr];
     else
-      return yydefgoto_[yylhs - yyntokens_];
+      return yydefgoto_[yysym - yyntokens_];
   }
 
   inline bool
@@ -1222,11 +1262,9 @@ namespace libdap {
   int
   D4FunctionParser::parse ()
   {
-    /// Whether yyla contains a lookahead.
-    bool yyempty = true;
-
     // State.
     int yyn;
+    /// Length of the RHS of the rule being reduced.
     int yylen = 0;
 
     // Error handling.
@@ -1239,9 +1277,6 @@ namespace libdap {
     /// The locations where the error started and ended.
     stack_symbol_type yyerror_range[3];
 
-    /// $$ and @$.
-    stack_symbol_type yylhs;
-
     /// The return value of parse ().
     int yyresult;
 
@@ -1253,7 +1288,7 @@ namespace libdap {
 
 
     // User initialization code.
-    #line 69 "d4_function_parser.yy" // lalr1.cc:727
+    #line 69 "d4_function_parser.yy" // lalr1.cc:741
 {
     // Initialize the initial location. This is printed when the parser builds
     // its own error messages - when the parse fails as opposed to when the 
@@ -1262,7 +1297,7 @@ namespace libdap {
     yyla.location.initialize (evaluator.expression());
 }
 
-#line 1266 "d4_function_parser.tab.cc" // lalr1.cc:727
+#line 1301 "d4_function_parser.tab.cc" // lalr1.cc:741
 
     /* Initialize the stack.  The initial state will be set in
        yynewstate, since the latter expects the semantical and the
@@ -1290,7 +1325,7 @@ namespace libdap {
       goto yydefault;
 
     // Read a lookahead token.
-    if (yyempty)
+    if (yyla.empty ())
       {
         YYCDEBUG << "Reading a token: ";
         try
@@ -1302,7 +1337,6 @@ namespace libdap {
             error (yyexc);
             goto yyerrlab1;
           }
-        yyempty = false;
       }
     YY_SYMBOL_PRINT ("Next token is", yyla);
 
@@ -1322,9 +1356,6 @@ namespace libdap {
         goto yyreduce;
       }
 
-    // Discard the token being shifted.
-    yyempty = true;
-
     // Count tokens shifted since error; after three, turn off error status.
     if (yyerrstatus_)
       --yyerrstatus_;
@@ -1347,11 +1378,13 @@ namespace libdap {
   `-----------------------------*/
   yyreduce:
     yylen = yyr2_[yyn];
-    yylhs.state = yy_lr_goto_state_(yystack_[yylen].state, yyr1_[yyn]);
-    /* Variants are always initialized to an empty instance of the
-       correct type. The default $$=$1 action is NOT applied when using
-       variants.  */
-      switch (yyr1_[yyn])
+    {
+      stack_symbol_type yylhs;
+      yylhs.state = yy_lr_goto_state_(yystack_[yylen].state, yyr1_[yyn]);
+      /* Variants are always initialized to an empty instance of the
+         correct type. The default '$$ = $1' action is NOT applied
+         when using variants.  */
+        switch (yyr1_[yyn])
     {
       case 7: // "function name"
       case 44: // fname
@@ -1440,494 +1473,495 @@ namespace libdap {
     }
 
 
-    // Compute the default @$.
-    {
-      slice<stack_symbol_type, stack_type> slice (yystack_, yylen);
-      YYLLOC_DEFAULT (yylhs.location, slice, yylen);
-    }
-
-    // Perform the reduction.
-    YY_REDUCE_PRINT (yyn);
-    try
+      // Compute the default @$.
       {
-        switch (yyn)
-          {
+        slice<stack_symbol_type, stack_type> slice (yystack_, yylen);
+        YYLLOC_DEFAULT (yylhs.location, slice, yylen);
+      }
+
+      // Perform the reduction.
+      YY_REDUCE_PRINT (yyn);
+      try
+        {
+          switch (yyn)
+            {
   case 2:
-#line 156 "d4_function_parser.yy" // lalr1.cc:847
+#line 156 "d4_function_parser.yy" // lalr1.cc:859
     { 
     evaluator.set_result(yystack_[0].value.as< D4RValueList* > ()); 
 }
-#line 1461 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1494 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 3:
-#line 162 "d4_function_parser.yy" // lalr1.cc:847
+#line 162 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValueList* > () = new D4RValueList(yystack_[0].value.as< D4RValue* > ()); 
 }
-#line 1469 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1502 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 4:
-#line 166 "d4_function_parser.yy" // lalr1.cc:847
+#line 166 "d4_function_parser.yy" // lalr1.cc:859
     { 
     yystack_[2].value.as< D4RValueList* > ()->add_rvalue(yystack_[0].value.as< D4RValue* > ());
     yylhs.value.as< D4RValueList* > () = yystack_[2].value.as< D4RValueList* > (); 
 }
-#line 1478 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1511 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 5:
-#line 173 "d4_function_parser.yy" // lalr1.cc:847
+#line 173 "d4_function_parser.yy" // lalr1.cc:859
     { 
     yylhs.value.as< D4RValue* > () = new D4RValue(yystack_[3].value.as< D4Function > (), yystack_[1].value.as< D4RValueList* > ()); // Build a D4RValue from a D4Function pointer and a D4RValueList 
 }
-#line 1486 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1519 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 6:
-#line 179 "d4_function_parser.yy" // lalr1.cc:847
+#line 179 "d4_function_parser.yy" // lalr1.cc:859
     { 
     D4Function f;
     if (!evaluator.sf_list()->find_function(yystack_[0].value.as< std::string > (), &f)) {
         // ...cloud use @1.{first,last}_column in these error messages.
-        throw Error("'" + yystack_[0].value.as< std::string > () + "' is not a registered DAP4 server function.");
+        throw Error(malformed_expr, "'" + yystack_[0].value.as< std::string > () + "' is not a registered DAP4 server function.");
     }
 
     yylhs.value.as< D4Function > () = f;
 }
-#line 1500 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1533 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 7:
-#line 191 "d4_function_parser.yy" // lalr1.cc:847
+#line 191 "d4_function_parser.yy" // lalr1.cc:859
     { 
     yylhs.value.as< D4RValueList* > () = new D4RValueList(yystack_[0].value.as< D4RValue* > ()); // build a D4RValueList from the D4RValue
 }
-#line 1508 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1541 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 8:
-#line 195 "d4_function_parser.yy" // lalr1.cc:847
+#line 195 "d4_function_parser.yy" // lalr1.cc:859
     { 
     yystack_[2].value.as< D4RValueList* > ()->add_rvalue(yystack_[0].value.as< D4RValue* > ());
     yylhs.value.as< D4RValueList* > () = yystack_[2].value.as< D4RValueList* > (); // Append the D4RValue ($3) to the D4RValueList ($1), then return
 }
-#line 1517 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1550 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 9:
-#line 202 "d4_function_parser.yy" // lalr1.cc:847
+#line 202 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = yystack_[0].value.as< D4RValue* > ();
 }
-#line 1525 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1558 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 10:
-#line 206 "d4_function_parser.yy" // lalr1.cc:847
+#line 206 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = yystack_[0].value.as< D4RValue* > ();
 }
-#line 1533 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1566 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 11:
-#line 210 "d4_function_parser.yy" // lalr1.cc:847
+#line 210 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = yystack_[0].value.as< D4RValue* > ();
 }
-#line 1541 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1574 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 12:
-#line 216 "d4_function_parser.yy" // lalr1.cc:847
+#line 216 "d4_function_parser.yy" // lalr1.cc:859
     {
     D4RValue *rvalue = evaluator.build_rvalue(yystack_[0].value.as< std::string > ());
     if (!rvalue) {
-        throw Error("'" + yystack_[0].value.as< std::string > () + "' is not a variable, number or string.");
+        throw Error(malformed_expr, "'" + yystack_[0].value.as< std::string > () + "' is not a variable, number or string.");
     }
     
     yylhs.value.as< D4RValue* > () = rvalue;
 }
-#line 1554 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1587 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 13:
-#line 228 "d4_function_parser.yy" // lalr1.cc:847
+#line 228 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_byte>* > ()));
     delete yystack_[1].value.as< std::vector<dods_byte>* > ();
 }
-#line 1563 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1596 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 14:
-#line 234 "d4_function_parser.yy" // lalr1.cc:847
+#line 234 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_byte>* > ()));
     delete yystack_[1].value.as< std::vector<dods_byte>* > ();
 }
-#line 1572 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1605 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 15:
-#line 240 "d4_function_parser.yy" // lalr1.cc:847
+#line 240 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_int8>* > ()));
     delete yystack_[1].value.as< std::vector<dods_int8>* > ();
 }
-#line 1581 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1614 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 16:
-#line 246 "d4_function_parser.yy" // lalr1.cc:847
+#line 246 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_uint16>* > ()));
     delete yystack_[1].value.as< std::vector<dods_uint16>* > ();
 }
-#line 1590 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1623 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 17:
-#line 252 "d4_function_parser.yy" // lalr1.cc:847
+#line 252 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_int16>* > ()));
     delete yystack_[1].value.as< std::vector<dods_int16>* > ();
 }
-#line 1599 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1632 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 18:
-#line 258 "d4_function_parser.yy" // lalr1.cc:847
+#line 258 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_uint32>* > ()));
     delete yystack_[1].value.as< std::vector<dods_uint32>* > ();
 }
-#line 1608 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1641 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 19:
-#line 264 "d4_function_parser.yy" // lalr1.cc:847
+#line 264 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_int32>* > ()));
     delete yystack_[1].value.as< std::vector<dods_int32>* > ();
 }
-#line 1617 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1650 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 20:
-#line 270 "d4_function_parser.yy" // lalr1.cc:847
+#line 270 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_uint64>* > ()));
     delete yystack_[1].value.as< std::vector<dods_uint64>* > ();
 }
-#line 1626 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1659 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 21:
-#line 276 "d4_function_parser.yy" // lalr1.cc:847
+#line 276 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_int64>* > ()));
     delete yystack_[1].value.as< std::vector<dods_int64>* > ();
 }
-#line 1635 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1668 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 22:
-#line 282 "d4_function_parser.yy" // lalr1.cc:847
+#line 282 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_float32>* > ()));
     delete yystack_[1].value.as< std::vector<dods_float32>* > ();
 }
-#line 1644 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1677 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 23:
-#line 288 "d4_function_parser.yy" // lalr1.cc:847
+#line 288 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< D4RValue* > () = new D4RValue(*(yystack_[1].value.as< std::vector<dods_float64>* > ()));
     delete yystack_[1].value.as< std::vector<dods_float64>* > ();
 }
-#line 1653 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1686 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 24:
-#line 300 "d4_function_parser.yy" // lalr1.cc:847
+#line 300 "d4_function_parser.yy" // lalr1.cc:859
     {
-    evaluator.set_arg_length_hint(get_ull(yystack_[0].value.as< std::string > ().c_str()));
+    evaluator.set_arg_length_hint(get_uint64(yystack_[0].value.as< std::string > ().c_str()));
 }
-#line 1661 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1694 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 25:
-#line 306 "d4_function_parser.yy" // lalr1.cc:847
+#line 306 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_byte>* > () = evaluator.init_arg_list(dods_byte(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0)));
 }
-#line 1669 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1702 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 26:
-#line 310 "d4_function_parser.yy" // lalr1.cc:847
+#line 310 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_byte>* > ()->push_back(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0));
     yylhs.value.as< std::vector<dods_byte>* > () = yystack_[2].value.as< std::vector<dods_byte>* > ();
 }
-#line 1678 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1711 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 27:
-#line 317 "d4_function_parser.yy" // lalr1.cc:847
+#line 317 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_int8>* > () = evaluator.init_arg_list(dods_int8(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0)));
 }
-#line 1686 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1719 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 28:
-#line 321 "d4_function_parser.yy" // lalr1.cc:847
+#line 321 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_int8>* > ()->push_back(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0));
     yylhs.value.as< std::vector<dods_int8>* > () = yystack_[2].value.as< std::vector<dods_int8>* > ();
 }
-#line 1695 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1728 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 29:
-#line 328 "d4_function_parser.yy" // lalr1.cc:847
+#line 328 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_uint16>* > () = evaluator.init_arg_list(dods_uint16(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0)));
 }
-#line 1703 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1736 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 30:
-#line 332 "d4_function_parser.yy" // lalr1.cc:847
+#line 332 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_uint16>* > ()->push_back(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0));
     yylhs.value.as< std::vector<dods_uint16>* > () = yystack_[2].value.as< std::vector<dods_uint16>* > ();
 }
-#line 1712 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1745 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 31:
-#line 339 "d4_function_parser.yy" // lalr1.cc:847
+#line 339 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_int16>* > () = evaluator.init_arg_list(dods_int16(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0)));
 }
-#line 1720 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1753 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 32:
-#line 343 "d4_function_parser.yy" // lalr1.cc:847
+#line 343 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_int16>* > ()->push_back(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0));
     yylhs.value.as< std::vector<dods_int16>* > () = yystack_[2].value.as< std::vector<dods_int16>* > ();
 }
-#line 1729 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1762 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 33:
-#line 350 "d4_function_parser.yy" // lalr1.cc:847
+#line 350 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_uint32>* > () = evaluator.init_arg_list(dods_uint32(strtoul(yystack_[0].value.as< std::string > ().c_str(), 0, 0)));
 }
-#line 1737 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1770 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 34:
-#line 354 "d4_function_parser.yy" // lalr1.cc:847
+#line 354 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_uint32>* > ()->push_back(strtoul(yystack_[0].value.as< std::string > ().c_str(), 0, 0));
     yylhs.value.as< std::vector<dods_uint32>* > () = yystack_[2].value.as< std::vector<dods_uint32>* > ();
 }
-#line 1746 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1779 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 35:
-#line 360 "d4_function_parser.yy" // lalr1.cc:847
+#line 360 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_int32>* > () = evaluator.init_arg_list(dods_int32(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0)));
 }
-#line 1754 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1787 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 36:
-#line 364 "d4_function_parser.yy" // lalr1.cc:847
+#line 364 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_int32>* > ()->push_back(strtol(yystack_[0].value.as< std::string > ().c_str(), 0, 0));
     yylhs.value.as< std::vector<dods_int32>* > () = yystack_[2].value.as< std::vector<dods_int32>* > ();
 }
-#line 1763 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1796 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 37:
-#line 371 "d4_function_parser.yy" // lalr1.cc:847
+#line 371 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_uint64>* > () = evaluator.init_arg_list(dods_uint64(strtoull(yystack_[0].value.as< std::string > ().c_str(), 0, 0)));
 }
-#line 1771 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1804 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 38:
-#line 375 "d4_function_parser.yy" // lalr1.cc:847
+#line 375 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_uint64>* > ()->push_back(strtoull(yystack_[0].value.as< std::string > ().c_str(), 0, 0));
     yylhs.value.as< std::vector<dods_uint64>* > () = yystack_[2].value.as< std::vector<dods_uint64>* > ();
 }
-#line 1780 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1813 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 39:
-#line 382 "d4_function_parser.yy" // lalr1.cc:847
+#line 382 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_int64>* > () = evaluator.init_arg_list(dods_int64(strtoll(yystack_[0].value.as< std::string > ().c_str(), 0, 0)));
 }
-#line 1788 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1821 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 40:
-#line 386 "d4_function_parser.yy" // lalr1.cc:847
+#line 386 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_int64>* > ()->push_back(strtoll(yystack_[0].value.as< std::string > ().c_str(), 0, 0));
     yylhs.value.as< std::vector<dods_int64>* > () = yystack_[2].value.as< std::vector<dods_int64>* > ();
 }
-#line 1797 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1830 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 41:
-#line 396 "d4_function_parser.yy" // lalr1.cc:847
+#line 396 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_float32>* > () = evaluator.init_arg_list(dods_float32(strtof(yystack_[0].value.as< std::string > ().c_str(), 0)));
 }
-#line 1805 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1838 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 42:
-#line 400 "d4_function_parser.yy" // lalr1.cc:847
+#line 400 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_float32>* > ()->push_back(strtof(yystack_[0].value.as< std::string > ().c_str(), 0));
     yylhs.value.as< std::vector<dods_float32>* > () = yystack_[2].value.as< std::vector<dods_float32>* > ();
 }
-#line 1814 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1847 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 43:
-#line 407 "d4_function_parser.yy" // lalr1.cc:847
+#line 407 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::vector<dods_float64>* > () = evaluator.init_arg_list(dods_float64(strtod(yystack_[0].value.as< std::string > ().c_str(), 0)));
 }
-#line 1822 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1855 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 44:
-#line 411 "d4_function_parser.yy" // lalr1.cc:847
+#line 411 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::vector<dods_float64>* > ()->push_back(strtod(yystack_[0].value.as< std::string > ().c_str(), 0));
     yylhs.value.as< std::vector<dods_float64>* > () = yystack_[2].value.as< std::vector<dods_float64>* > ();
 }
-#line 1831 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1864 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 45:
-#line 418 "d4_function_parser.yy" // lalr1.cc:847
+#line 418 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::string > () = yystack_[0].value.as< std::string > ();
 }
-#line 1839 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1872 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 46:
-#line 422 "d4_function_parser.yy" // lalr1.cc:847
+#line 422 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::string > ().append("/");
     yylhs.value.as< std::string > ().append(yystack_[0].value.as< std::string > ());
 }
-#line 1848 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1881 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 47:
-#line 427 "d4_function_parser.yy" // lalr1.cc:847
+#line 427 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::string > ().append("/");
     yystack_[2].value.as< std::string > ().append(yystack_[0].value.as< std::string > ());
     yylhs.value.as< std::string > () = yystack_[2].value.as< std::string > ();
 }
-#line 1858 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1891 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 48:
-#line 435 "d4_function_parser.yy" // lalr1.cc:847
+#line 435 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::string > ().append("/");
     yylhs.value.as< std::string > ().append(yystack_[0].value.as< std::string > ());
 }
-#line 1867 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1900 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 49:
-#line 440 "d4_function_parser.yy" // lalr1.cc:847
+#line 440 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::string > ().append(".");
     yystack_[2].value.as< std::string > ().append(yystack_[0].value.as< std::string > ());
     yylhs.value.as< std::string > () = yystack_[2].value.as< std::string > ();
 }
-#line 1877 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1910 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 50:
-#line 448 "d4_function_parser.yy" // lalr1.cc:847
+#line 448 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::string > () = yystack_[0].value.as< std::string > ();
 }
-#line 1885 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1918 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 51:
-#line 452 "d4_function_parser.yy" // lalr1.cc:847
+#line 452 "d4_function_parser.yy" // lalr1.cc:859
     {
     yystack_[2].value.as< std::string > ().append(".");
     yystack_[2].value.as< std::string > ().append(yystack_[0].value.as< std::string > ());
     yylhs.value.as< std::string > () = yystack_[2].value.as< std::string > ();
 }
-#line 1895 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1928 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 52:
-#line 463 "d4_function_parser.yy" // lalr1.cc:847
+#line 463 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::string > ()=yystack_[0].value.as< std::string > ();
 }
-#line 1903 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1936 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
   case 53:
-#line 467 "d4_function_parser.yy" // lalr1.cc:847
+#line 467 "d4_function_parser.yy" // lalr1.cc:859
     {
     yylhs.value.as< std::string > ()=yystack_[0].value.as< std::string > ();
 }
-#line 1911 "d4_function_parser.tab.cc" // lalr1.cc:847
+#line 1944 "d4_function_parser.tab.cc" // lalr1.cc:859
     break;
 
 
-#line 1915 "d4_function_parser.tab.cc" // lalr1.cc:847
-          default:
-            break;
-          }
-      }
-    catch (const syntax_error& yyexc)
-      {
-        error (yyexc);
-        YYERROR;
-      }
-    YY_SYMBOL_PRINT ("-> $$ =", yylhs);
-    yypop_ (yylen);
-    yylen = 0;
-    YY_STACK_PRINT ();
+#line 1948 "d4_function_parser.tab.cc" // lalr1.cc:859
+            default:
+              break;
+            }
+        }
+      catch (const syntax_error& yyexc)
+        {
+          error (yyexc);
+          YYERROR;
+        }
+      YY_SYMBOL_PRINT ("-> $$ =", yylhs);
+      yypop_ (yylen);
+      yylen = 0;
+      YY_STACK_PRINT ();
 
-    // Shift the result of the reduction.
-    yypush_ (YY_NULLPTR, yylhs);
+      // Shift the result of the reduction.
+      yypush_ (YY_NULLPTR, yylhs);
+    }
     goto yynewstate;
 
   /*--------------------------------------.
@@ -1938,8 +1972,7 @@ namespace libdap {
     if (!yyerrstatus_)
       {
         ++yynerrs_;
-        error (yyla.location, yysyntax_error_ (yystack_[0].state,
-                                           yyempty ? yyempty_ : yyla.type_get ()));
+        error (yyla.location, yysyntax_error_ (yystack_[0].state, yyla));
       }
 
 
@@ -1952,10 +1985,10 @@ namespace libdap {
         // Return failure if at end of input.
         if (yyla.type_get () == yyeof_)
           YYABORT;
-        else if (!yyempty)
+        else if (!yyla.empty ())
           {
             yy_destroy_ ("Error: discarding", yyla);
-            yyempty = true;
+            yyla.clear ();
           }
       }
 
@@ -1974,9 +2007,6 @@ namespace libdap {
     if (false)
       goto yyerrorlab;
     yyerror_range[1].location = yystack_[yylen - 1].location;
-    /* $$ was initialized before running the user action.  */
-    YY_SYMBOL_PRINT ("Error: discarding", yylhs);
-    yylhs.~stack_symbol_type();
     /* Do not reclaim the symbols of the rule whose action triggered
        this YYERROR.  */
     yypop_ (yylen);
@@ -2034,7 +2064,7 @@ namespace libdap {
     goto yyreturn;
 
   yyreturn:
-    if (!yyempty)
+    if (!yyla.empty ())
       yy_destroy_ ("Cleanup: discarding lookahead", yyla);
 
     /* Do not reclaim the symbols of the rule whose action triggered
@@ -2054,7 +2084,7 @@ namespace libdap {
                  << std::endl;
         // Do not try to display the values of the reclaimed symbols,
         // as their printer might throw an exception.
-        if (!yyempty)
+        if (!yyla.empty ())
           yy_destroy_ (YY_NULLPTR, yyla);
 
         while (1 < yystack_.size ())
@@ -2074,9 +2104,8 @@ namespace libdap {
 
   // Generate an error message.
   std::string
-  D4FunctionParser::yysyntax_error_ (state_type yystate, symbol_number_type yytoken) const
+  D4FunctionParser::yysyntax_error_ (state_type yystate, const symbol_type& yyla) const
   {
-    std::string yyres;
     // Number of reported tokens (one for the "unexpected", one per
     // "expected").
     size_t yycount = 0;
@@ -2090,7 +2119,7 @@ namespace libdap {
          the only way this function was invoked is if the default action
          is an error action.  In that case, don't check for expected
          tokens because there are none.
-       - The only way there can be no lookahead present (in yytoken) is
+       - The only way there can be no lookahead present (in yyla) is
          if this state is a consistent state with a default action.
          Thus, detecting the absence of a lookahead is sufficient to
          determine that there is no unexpected or expected token to
@@ -2110,8 +2139,9 @@ namespace libdap {
          token that will not be accepted due to an error action in a
          later state.
     */
-    if (yytoken != yyempty_)
+    if (!yyla.empty ())
       {
+        int yytoken = yyla.type_get ();
         yyarg[yycount++] = yytname_[yytoken];
         int yyn = yypact_[yystate];
         if (!yy_pact_value_is_default_ (yyn))
@@ -2154,6 +2184,7 @@ namespace libdap {
 #undef YYCASE_
       }
 
+    std::string yyres;
     // Argument number.
     size_t yyi = 0;
     for (char const* yyp = yyformat; *yyp; ++yyp)
@@ -2417,10 +2448,10 @@ namespace libdap {
       return undef_token_;
   }
 
-#line 34 "d4_function_parser.yy" // lalr1.cc:1157
+#line 34 "d4_function_parser.yy" // lalr1.cc:1167
 } // libdap
-#line 2423 "d4_function_parser.tab.cc" // lalr1.cc:1157
-#line 472 "d4_function_parser.yy" // lalr1.cc:1158
+#line 2454 "d4_function_parser.tab.cc" // lalr1.cc:1167
+#line 472 "d4_function_parser.yy" // lalr1.cc:1168
 
 
 // Forward the error to the driver for handling. The location parameter
