@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.1.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.1"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -175,7 +175,7 @@ extern int dds_line_num;	/* defined in dds.lex */
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
 #line 131 "dds.yy" /* yacc.c:355  */
@@ -185,6 +185,8 @@ union YYSTYPE
 
 #line 187 "dds.tab.cc" /* yacc.c:355  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
@@ -198,7 +200,7 @@ int ddsparse (parser_arg *arg);
 
 /* Copy the second part of user declarations.  */
 
-#line 202 "dds.tab.cc" /* yacc.c:358  */
+#line 204 "dds.tab.cc" /* yacc.c:358  */
 /* Unqualified %code blocks.  */
 #line 93 "dds.yy" /* yacc.c:359  */
 
@@ -228,7 +230,7 @@ void invalid_declaration(parser_arg *arg, string semantic_err_msg,
 			 char *type, char *name);
 
 
-#line 232 "dds.tab.cc" /* yacc.c:359  */
+#line 234 "dds.tab.cc" /* yacc.c:359  */
 
 #ifdef short
 # undef short
@@ -1395,7 +1397,7 @@ yyreduce:
 		    if (!ctor)
 		    	ctor = new stack<BaseType *>;
         }
-#line 1399 "dds.tab.cc" /* yacc.c:1646  */
+#line 1401 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 3:
@@ -1403,7 +1405,7 @@ yyreduce:
     {
 		    delete ctor; ctor = 0;
 		}
-#line 1407 "dds.tab.cc" /* yacc.c:1646  */
+#line 1409 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 6:
@@ -1411,7 +1413,7 @@ yyreduce:
     {
 		    (yyval.boolean) = (yyvsp[-3].boolean) && (yyvsp[-1].boolean);
 		}
-#line 1415 "dds.tab.cc" /* yacc.c:1646  */
+#line 1417 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 7:
@@ -1421,7 +1423,7 @@ yyreduce:
 		    error_exit_cleanup();
 		    YYABORT;
 		}
-#line 1425 "dds.tab.cc" /* yacc.c:1646  */
+#line 1427 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 8:
@@ -1429,19 +1431,19 @@ yyreduce:
     {
 		    (yyval.boolean) = true;
 		}
-#line 1433 "dds.tab.cc" /* yacc.c:1646  */
+#line 1435 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 9:
 #line 196 "dds.yy" /* yacc.c:1646  */
     { (yyval.boolean) = true; }
-#line 1439 "dds.tab.cc" /* yacc.c:1646  */
+#line 1441 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 10:
 #line 197 "dds.yy" /* yacc.c:1646  */
     { (yyval.boolean) = true; }
-#line 1445 "dds.tab.cc" /* yacc.c:1646  */
+#line 1447 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 11:
@@ -1458,7 +1460,7 @@ yyreduce:
             strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
             (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1462 "dds.tab.cc" /* yacc.c:1646  */
+#line 1464 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 12:
@@ -1468,7 +1470,7 @@ yyreduce:
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1472 "dds.tab.cc" /* yacc.c:1646  */
+#line 1474 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 13:
@@ -1486,7 +1488,7 @@ yyreduce:
             strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
             (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1490 "dds.tab.cc" /* yacc.c:1646  */
+#line 1492 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 14:
@@ -1496,7 +1498,7 @@ yyreduce:
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1500 "dds.tab.cc" /* yacc.c:1646  */
+#line 1502 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 15:
@@ -1514,14 +1516,14 @@ yyreduce:
             strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
             (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1518 "dds.tab.cc" /* yacc.c:1646  */
+#line 1520 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 16:
 #line 263 "dds.yy" /* yacc.c:1646  */
     { 
 		    if (is_keyword(string((yyvsp[-1].word)), "array")) {
-			    part = array;
+			    part = libdap::array;
 			}
 		    else {
 			    ostringstream msg;
@@ -1530,7 +1532,7 @@ yyreduce:
 			    YYABORT;
 		    }
         }
-#line 1534 "dds.tab.cc" /* yacc.c:1646  */
+#line 1536 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 17:
@@ -1546,7 +1548,7 @@ yyreduce:
 			    YYABORT;
 		    }
         }
-#line 1550 "dds.tab.cc" /* yacc.c:1646  */
+#line 1552 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 18:
@@ -1556,7 +1558,7 @@ yyreduce:
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1560 "dds.tab.cc" /* yacc.c:1646  */
+#line 1562 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 19:
@@ -1575,7 +1577,7 @@ yyreduce:
         strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
         (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1579 "dds.tab.cc" /* yacc.c:1646  */
+#line 1581 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 20:
@@ -1586,7 +1588,7 @@ yyreduce:
 		    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		    YYABORT;
 		}
-#line 1590 "dds.tab.cc" /* yacc.c:1646  */
+#line 1592 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 21:
@@ -1594,7 +1596,7 @@ yyreduce:
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewStructure()); 
 		}
-#line 1598 "dds.tab.cc" /* yacc.c:1646  */
+#line 1600 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 22:
@@ -1602,7 +1604,7 @@ yyreduce:
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewSequence()); 
 		}
-#line 1606 "dds.tab.cc" /* yacc.c:1646  */
+#line 1608 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 23:
@@ -1610,67 +1612,67 @@ yyreduce:
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewGrid()); 
 		}
-#line 1614 "dds.tab.cc" /* yacc.c:1646  */
+#line 1616 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 24:
 #line 336 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewByte(); }
-#line 1620 "dds.tab.cc" /* yacc.c:1646  */
+#line 1622 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 25:
 #line 337 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt16(); }
-#line 1626 "dds.tab.cc" /* yacc.c:1646  */
+#line 1628 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 26:
 #line 338 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt16(); }
-#line 1632 "dds.tab.cc" /* yacc.c:1646  */
+#line 1634 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 27:
 #line 339 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt32(); }
-#line 1638 "dds.tab.cc" /* yacc.c:1646  */
+#line 1640 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 28:
 #line 340 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt32(); }
-#line 1644 "dds.tab.cc" /* yacc.c:1646  */
+#line 1646 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 29:
 #line 341 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat32(); }
-#line 1650 "dds.tab.cc" /* yacc.c:1646  */
+#line 1652 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 30:
 #line 342 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat64(); }
-#line 1656 "dds.tab.cc" /* yacc.c:1646  */
+#line 1658 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 31:
 #line 343 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewStr(); }
-#line 1662 "dds.tab.cc" /* yacc.c:1646  */
+#line 1664 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 32:
 #line 344 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUrl(); }
-#line 1668 "dds.tab.cc" /* yacc.c:1646  */
+#line 1670 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 33:
 #line 347 "dds.yy" /* yacc.c:1646  */
     { current->set_name((yyvsp[0].word)); }
-#line 1674 "dds.tab.cc" /* yacc.c:1646  */
+#line 1676 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 49:
@@ -1694,7 +1696,7 @@ yyreduce:
 
 		    (yyval.boolean) = true;
 		 }
-#line 1698 "dds.tab.cc" /* yacc.c:1646  */
+#line 1700 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 50:
@@ -1702,7 +1704,7 @@ yyreduce:
     {
 		     if (!id) id = new string((yyvsp[0].word));
 		 }
-#line 1706 "dds.tab.cc" /* yacc.c:1646  */
+#line 1708 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 51:
@@ -1728,7 +1730,7 @@ yyreduce:
 
 		     delete id; id = 0;
 		 }
-#line 1732 "dds.tab.cc" /* yacc.c:1646  */
+#line 1734 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 52:
@@ -1736,7 +1738,7 @@ yyreduce:
     {
 		     (yyval.boolean) = true;
 		 }
-#line 1740 "dds.tab.cc" /* yacc.c:1646  */
+#line 1742 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 53:
@@ -1748,19 +1750,19 @@ yyreduce:
 		     parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		     YYABORT;
 		 }
-#line 1752 "dds.tab.cc" /* yacc.c:1646  */
+#line 1754 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 54:
 #line 419 "dds.yy" /* yacc.c:1646  */
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); (yyval.boolean) = true;}
-#line 1758 "dds.tab.cc" /* yacc.c:1646  */
+#line 1760 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 55:
 #line 420 "dds.yy" /* yacc.c:1646  */
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); (yyval.boolean) = true; }
-#line 1764 "dds.tab.cc" /* yacc.c:1646  */
+#line 1766 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 56:
@@ -1772,11 +1774,11 @@ yyreduce:
 		    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		    YYABORT;
 		}
-#line 1776 "dds.tab.cc" /* yacc.c:1646  */
+#line 1778 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
 
-#line 1780 "dds.tab.cc" /* yacc.c:1646  */
+#line 1782 "dds.tab.cc" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
