@@ -206,10 +206,10 @@ intern_data(DMR *dataset, /*const string &constraint,*/ bool series_values)
     // Mark all variables to be sent in their entirety. No CEs are used
     // when 'interning' variables' data.
     dataset->root()->set_send_p(true);
-
+#if 0
     Crc32 checksum;
-
-    dataset->root()->intern_data(checksum/*, *dataset, eval*/);
+#endif
+    dataset->root()->intern_data(/*checksum, *dataset, eval*/);
 }
 
 DMR *
@@ -236,6 +236,11 @@ read_data_plain(const string &file_name, bool debug)
         cis.read(chunk, chunk_size);
         // parse char * with given size
     	D4ParserSax2 parser;
+
+    	// Mirror the behavior in D4Connect where we are permissive with DAP4
+    	// data responses' parsing, as per Hyrax-98 in Jira. jhrg 4/13/16
+    	parser.set_strict(false);
+
     	// '-2' to discard the CRLF pair
         parser.intern(chunk, chunk_size-2, dmr, debug);
     }
