@@ -101,19 +101,19 @@ public:
     	D4Enum e("second", dods_byte_c);
     	dods_byte db = 200;
     	e.set_value(db);
-    	CPPUNIT_ASSERT(e.d_buf.ui8 == 200);
+    	CPPUNIT_ASSERT(e.d_buf == 200);
     }
 
     void test_set_value2() {
     	D4Enum e("second", dods_byte_c);
     	e.set_value(200);
-    	CPPUNIT_ASSERT(e.d_buf.ui8 == 200);
+    	CPPUNIT_ASSERT(e.d_buf == 200);
     }
 
     void test_set_value3() {
     	D4Enum e("third", dods_int32_c);
     	e.set_value(-65535);
-    	CPPUNIT_ASSERT(e.d_buf.i32 == -65535);
+    	CPPUNIT_ASSERT(e.d_buf == -65535);
     }
 
     void test_value() {
@@ -139,7 +139,7 @@ public:
     	D4Enum f(e);
     	CPPUNIT_ASSERT(f.d_element_type == dods_byte_c);
     	CPPUNIT_ASSERT(f.name() == "second");
-    	CPPUNIT_ASSERT(f.d_buf.ui8 == 200);
+    	CPPUNIT_ASSERT(f.d_buf == 200);
     }
 
     void test_assignment() {
@@ -149,7 +149,7 @@ public:
     	D4Enum f = e;
     	CPPUNIT_ASSERT(f.d_element_type == dods_byte_c);
     	CPPUNIT_ASSERT(f.name() == "second");
-    	CPPUNIT_ASSERT(f.d_buf.ui8 == 200);
+    	CPPUNIT_ASSERT(f.d_buf == 200);
     }
 
     void test_print() {
