@@ -52,11 +52,16 @@
 #include "test_config.h"
 
 static bool debug = false;
-const string path = (string)TEST_SRC_DIR + "/D4-marshaller";
 
 #undef DBG
 #define DBG(x) do { if (debug) (x); } while(false);
 
+#if WORDS_BIGENDIAN
+const static string path = string(TEST_SRC_DIR) + "/D4-marshaller/big-endian";
+#else
+const static string path = string(TEST_SRC_DIR) + "/D4-marshaller/little-endian";
+#endif
+
 using namespace std;
 using namespace libdap;
 
@@ -82,7 +87,7 @@ class D4UnMarshallerTest: public CppUnit::TestFixture {
 
 #else
 
-#ifdef WORDS_BIGENDIAN
+#ifdef __BIG_ENDIAN__
         return true;
 #else
         return false;
@@ -111,56 +116,62 @@ public:
 	    string file = path + "/test_scalars_1_bin.dat";
 	    DBG(cerr << "file: " << file << endl);
 	    in.open(file.c_str(), fstream::binary | fstream::in);
-            D4StreamUnMarshaller dsm(in, is_host_big_endian());
+
+	    // Don't use is_host_big_endian() because these tests should
+	    // never 'twiddle bytes' They are always testing little to little
+	    // of big to big
+            D4StreamUnMarshaller dsm(in, 0 /*is_host_big_endian()*/);
 
             dods_byte b;
             dsm.get_byte(b);
             CPPUNIT_ASSERT(b == 17);
             string ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
+            DBG(cerr << "ck: " << ck << endl);
+            // Same checksum for both big- and little-endian
             CPPUNIT_ASSERT(ck == "b8b2cf7f");
 
             dods_int16 i1;
             dsm.get_int16(i1);
             CPPUNIT_ASSERT(i1 == 17);
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "120031ef");
+            DBG(cerr << "ck: " << ck << endl);
+            // little-endian || big-endian checksum values
+            CPPUNIT_ASSERT(ck == "120031ef" || ck == "2b69320d");
 
             dods_int32 i2;
             dsm.get_int32(i2);
             CPPUNIT_ASSERT(i2 == 17);
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "c9e1efe6");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "c9e1efe6" || ck == "4bf4ffee");
 
             dods_int64 i3;
             dsm.get_int64(i3);
             CPPUNIT_ASSERT(i3 == 17);
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "d533eedc");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "d533eedc" || ck == "0f92ff9b");
 
             dods_uint16 ui1;
             dsm.get_uint16(ui1);
             CPPUNIT_ASSERT(ui1 == 17);
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "120031ef");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "120031ef" || ck == "2b69320d");
 
             dods_uint32 ui2;
             dsm.get_uint32(ui2);
             CPPUNIT_ASSERT(ui2 == 17);
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "c9e1efe6");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "c9e1efe6" || ck == "4bf4ffee");
 
             dods_uint64 ui3;
             dsm.get_uint64(ui3);
             CPPUNIT_ASSERT(ui3 == 17);
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "d533eedc");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "d533eedc" || ck == "0f92ff9b");
         }
         catch (Error &e) {
             cerr << "Error: " << e.get_error_message() << endl;
@@ -181,21 +192,21 @@ public:
         try {
 	    string file = path + "/test_scalars_2_bin.dat";
             in.open(file.c_str(), fstream::binary | fstream::in);
-            D4StreamUnMarshaller dsm(in, is_host_big_endian());
+            D4StreamUnMarshaller dsm(in, 0);
 
             dods_float32 r1;
             dsm.get_float32(r1);
             CPPUNIT_ASSERT(r1 == 17.0);
             string ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "d3c5bc59");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "d3c5bc59" || ck == "edcaaa7c");
 
             dods_float64 r2;
             dsm.get_float64(r2);
             CPPUNIT_ASSERT(r2 == 17.0);
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "d5a3994b");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "d5a3994b" || ck == "42abb362");
         }
         catch (Error &e) {
             cerr << "Error: " << e.get_error_message() << endl;
@@ -215,20 +226,20 @@ public:
         try {
 	    string file = path + "/test_scalars_3_bin.dat";
             in.open(file.c_str(), fstream::binary | fstream::in);
-            D4StreamUnMarshaller dsm(in, is_host_big_endian());
+            D4StreamUnMarshaller dsm(in, 0);
 
             string s;
             dsm.get_str(s);
             CPPUNIT_ASSERT(s == "This is a test string with 40 characters");
             string ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
+            DBG(cerr << "ck: " << ck << endl);
             CPPUNIT_ASSERT(ck == "af117544");
 
             string u;
             dsm.get_url(u);
             CPPUNIT_ASSERT(u == "http://www.opendap.org/lame/unit/test");
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
+            DBG(cerr << "ck: " << ck << endl);
             CPPUNIT_ASSERT(ck == "41e10081");
         }
         catch (Error &e) {
@@ -249,7 +260,7 @@ public:
         try {
 	    string file = path + "/test_opaque_1_bin.dat";
             in.open(file.c_str(), fstream::binary | fstream::in);
-            D4StreamUnMarshaller dsm(in, is_host_big_endian());
+            D4StreamUnMarshaller dsm(in, 0);
 
             char *buf2;
             int64_t len;
@@ -258,7 +269,7 @@ public:
             for (int i = 0; i < 32768; ++i)
                 CPPUNIT_ASSERT(buf2[i] == i % (1 << 7));
             string ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
+            DBG(cerr << "ck: " << ck << endl);
             CPPUNIT_ASSERT(ck == "199ad7f5");
 
             delete buf2;
@@ -281,23 +292,23 @@ public:
         try {
 	    string file = path + "/test_vector_1_bin.dat";
             in.open(file.c_str(), fstream::binary | fstream::in);
-            D4StreamUnMarshaller dsm(in, is_host_big_endian());
+            D4StreamUnMarshaller dsm(in, 0);
 
             vector<unsigned char> buf1(32768);
             dsm.get_vector(reinterpret_cast<char*>(&buf1[0]), 32768);
             for (int i = 0; i < 32768; ++i)
                 CPPUNIT_ASSERT(buf1[i] == i % (1 << 7));
             string ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "199ad7f5");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "199ad7f5" || ck == "199ad7f5");
 
             vector<dods_int32> buf2(32768);
             dsm.get_vector(reinterpret_cast<char*>(&buf2[0]), 32768, sizeof(dods_int32));
             for (int i = 0; i < 32768; ++i)
                 CPPUNIT_ASSERT(buf2[i] == i % (1 << 9));
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "5c1bf29f");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "5c1bf29f" || ck == "8efd2d3d");
 
             vector<dods_float64> buf3(32768);
             dsm.get_vector_float64(reinterpret_cast<char*>(&buf3[0]), 32768);
@@ -307,8 +318,8 @@ public:
                 CPPUNIT_ASSERT(buf3[i] == i % (1 << 9));
             }
             ck = dsm.get_checksum_str();
-            DBG2(cerr << "ck: " << ck << endl);
-            CPPUNIT_ASSERT(ck == "aafc2a91");
+            DBG(cerr << "ck: " << ck << endl);
+            CPPUNIT_ASSERT(ck == "aafc2a91" || ck == "7bdf9931");
        }
         catch (Error &e) {
             cerr << "Error: " << e.get_error_message() << endl;
