@@ -100,7 +100,7 @@ bool is_host_big_endian()
 
 #else
 
-#ifdef WORDS_BIGENDIAN
+#if WORDS_BIGENDIAN
     return true;
 #else
     return false;
@@ -331,6 +331,9 @@ template<class T> static void extract_double_array_helper(Array * a, vector<doub
  * array using 'new double[n]' so delete[] MUST be used when you are done
  * the data.
  *
+ * @note Before you call this function, you must call read on the array,
+ * or load the array with values and set the read_p property.
+ *
  * @note Support added for DAP4.
  * @param a Extract value from this Array.
  * @param dest Put the values in this vector. A value-result parameter.
@@ -346,7 +349,7 @@ void extract_double_array(Array *a, vector<double> &dest)
         throw Error(malformed_expr, "The function requires a DAP numeric-type array argument.");
 
     if (!a->read_p())
-        throw InternalErr(__FILE__, __LINE__, string("The Array '") + a->name() + "'does not contain values.");
+        throw InternalErr(__FILE__, __LINE__, string("The Array '") + a->name() + "' does not contain values.");
 
     dest.resize(a->length());
 
@@ -1220,14 +1223,14 @@ string open_temp_fstream(ofstream &f, const string &name_template, const string
     // Use mkstemp to make and open the temp file atomically
     int tmpfile = mkstemps(&name[0], suffix.length());
     if (tmpfile == -1)
-        throw Error("Could not make a temporary file.");
+        throw Error(internal_error, "Could not make a temporary file.");
     // Open the file using C++ ofstream; get a C++ fstream object
     f.open(&name[0]);
     // Close the file descriptor; the file stays open because of the fstream object
     close(tmpfile);
     // Now test that the fstream object is valid
     if (f.fail())
-        throw Error("Could not make a temporary file.");
+        throw Error(internal_error, "Could not make a temporary file.");
 
     return string(&name[0]);
 }
